@@ -8,14 +8,14 @@
 # @Software     : PyCharm
 # @Description  : 
 
-import os
-import numpy as np
-import streamlit as st
+from meutils.common import *
+from meutils.zk_utils import get_zk_config
 
+import streamlit as st
 from paddleocr import PaddleOCR
-from appzoo.utils.image_utils import *
+from PIL import Image
+from appzoo.utils.image_utils import ocr_result_image
 from appzoo.utils.streamlit_utils import *
-from appzoo.utils.zk_utils import get_zk_config
 
 ocr = PaddleOCR(use_angle_cls=True, lang="ch")
 
